@@ -15,7 +15,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.54'
+__version__ = '0.1.56'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -48,7 +48,9 @@ __info__ = {
     '2022/10/23: 0.1.51 get_all_stock_code_name_dict() 加入 _api 參數',
     '2022/10/25: 0.1.52 price_ticks_offset_AB_dec() 還有其他改成Decimal',
     '2022/10/30: 0.1.53 price_ticks_offsets_dec()',
-    '2022/11/24: 0.1.54 修正一個 redis 非常奇怪的問題'
+    '2022/11/24: 0.1.54 修正一個 redis 非常奇怪的問題',
+    '2022/11/27: 0.1.55 加入 shioaji_kline, KLine OHLC',
+    '2022/12/22: 0.1.56 加入 get_new_warrant_list() and add_new_issued_warrant_to_bible()'
 
 }
 
